#!/bin/sh

# muppages.sh

FILENAME=$1
shift

PAGES=$1
shift

USAGE="Usage: FILENAME PAGES [ -D macroname ]"

ERRFILE="${FILENAME}.err"

# ----------------------------------------------------------------------- #
# Validate command line options                                           #
# ----------------------------------------------------------------------- #

while getopts ":D:" ARG_STRING
do
    case $ARG_STRING in
    D)	MACRODEF=$OPTARG
	;;
    *)	echo $USAGE
	exit;;
    esac
done

if [ -n MACRODEF ]
then
    case $MACRODEF in
    ORIG) 
	SCORETYPE="_o"
	EXTRAOPTS="-D ORIG"
	;;
    SCORE) 
	SCORETYPE="_r"
	EXTRAOPTS="-D ARR"
	;;
    PS) 
	SCORETYPE="_rs"
	EXTRAOPTS="-D ARR -D SP -D DESCANT -s 1 -c 3"
	;;
    PT) 
	SCORETYPE="_rt"
	EXTRAOPTS="-D ARR -D SP -D TREBLE -s 2 -c 3"
	;;
    PB) 
	SCORETYPE="_rb"
	EXTRAOPTS="-D ARR -D SP -D BASS -s 3 -c 3"
	;;
    *)  
	echo Macronames: SCORE, PS, PT, PB
	exit;;
    esac
fi

# ----------------------------------------------------------------------- #
# Define functions                                                        #
# ----------------------------------------------------------------------- #

muppage() { 
    MUPOPTS=""
    PAGE=$2
    INFILE=${1}.mup 
    OUTFILE=${1}${SCORETYPE}_p${PAGE}.ps
    if [ "${EXTRAOPTS}" ]; then MUPOPTS="${EXTRAOPTS} "; fi
    MUPOPTS="${MUPOPTS} -D $MACRODEF -o ${PAGE} ${INFILE} -f ${OUTFILE} -e ${ERRFILE}"
    mup ${MUPOPTS} > /dev/null 2>&1 
    if [ $? -gt 0 ] 
    then 
	if [ -s ${ERRFILE} ]
	then
	    cat ${ERRFILE}
	else
	    echo "mup ${MUPOPTS}"
	fi
	exit 
    fi
    rm -f ${ERRFILE} > /dev/null 2>&1 
}

epsipage() { 
    PAGE=$2
    INFILE=${1}${SCORETYPE}_p${PAGE}.ps
    ps2epsi ${INFILE} > ${ERRFILE} 2>&1 
    if [ $? -gt 0 ]
    then
	cat ${ERRFILE}
	exit
    fi
    rm -f ${INFILE} > /dev/null 2>&1 
    rm -f ${ERRFILE} > /dev/null 2>&1 
}

domovement() {
    i=1; maxp=$1
    while [ $i -le $maxp ]
    do
	muppage $2 $i || exit 1
	epsipage $2 $i || exit 1
	let i=$i+1
    done
}


domovement $PAGES $FILENAME
